/* GLOBAL PRODUCTION: FIRMS, CONTRACTS AND TRADE STRUCTURE */
/* CHAPTER 5 */
/* by Pol Antras, Harvard University, with the assistance of BooKang Seol. */
/* v 2.0.1, Last Updated: September 4th, 2014 */

version 13.1
set more off
capture log close
set matsize 2000

********************
* FILE DIRECTORIES *
********************
global root "C:/Users/Pol Antras/Documents/A_Active Papers/CREILectures/Data Programs Posted Online"
*Note the Users: change above line to the local directory where you downloaded the data and programs
cd "$root"
mkdir "$root/Tables_Ch5"
*Note the Users: run the two lines of code above before running the "log using" or "outreg commands" FOR THE FIRST TIME; these commands should then be silenced
global Tables "$root/Tables_Ch5"
log using "$Tables/analysis_chapter5_final"


*****************************
* BUILD CROSS-INDUSTRY DATA *
*****************************
** NAICS
cd "$root"
use "global_production_naics", clear
	// copy labels
foreach v of varlist imp_tot-kotherequip_pay{
 	local l`v' : variable label `v'
}
 
collapse (sum) imp* exp* (mean) dispersion-kotherequip_pay , by(naics year)
	
	// paste labels
foreach v of varlist imp_tot-kotherequip_pay {
 	label var `v' "`l`v''"
}

label data "Cross-Industry NAICS"
save "global_production_crossindustry_naics.dta", replace

** IO2002
use "global_production_io2002", clear

	// copy labels
foreach v of varlist imp_tot-flex{
 	local l`v' : variable label `v'
}
 
collapse (sum)imp* exp* (mean) discountm_gw-flex, by(io2002 year)
	
	// paste labels
foreach v of varlist imp_tot-flex{
 	label var `v' "`l`v''"
}

	// discount variables
drop discount* xt* 
ren i_discountm_gw discountm_gw
ren i_discountx_gw discountx_gw
ren i_discountm_gwnt discountm_gwnt
ren i_xtdiscountm_gw xtdiscountm_gw
ren i_xtdiscountx_gw xtdiscountx_gw

foreach var in discountm_gw discountx_gw discountm_gwnt xtdiscountm_gw xtdiscountx_gw {
replace `var'=0 if io2002=="331314" & `var'==.
}

label data "Cross-Industry IO2002"
*drop if io2002=="334411" 
* Note to Users: the above line, when activated, allows one to check the robustness of the results to dropping industry IO334411, whose R&D intensity is an outlier 

save "global_production_crossindustry_io2002.dta", replace

*************
* TABLE 5.2 *
*************
use "global_production_crossindustry_naics", clear
drop if naics=="33641X"
* Note to Users: See the Data Appendix for a justification for dropping the composite industry IO33641X

gen fs= imp_tot / (imp_tot + vship*1000000 - exp_tot)
gen kl= log(cap / emp )
gen sl=log((emp-prode)/emp)
gen buildl=log(plant / emp )
gen equipl=log(equip / emp )
gen rd=log(0.001+ rd_complete)
gen goodshare=0
replace goodshare=1 if fs<=1 & fs>=0

* Note to Users: the outreg2 commands below produces spreadsheets with OLS estimates and beta coefficients. 
* The standard errors of the beta coefficients can be computed manually manipulating the spreadsheet.
* For other Tables, beta coefficients and standard errors are obtained more directly by first standardizing all variables.

** 5.2, col 1 
areg fs tcosts tariff kl sl rd, absorb(year) cluster(naics)
	outreg2 tcosts tariff kl sl rd  using "$Tables/Table5_2.xls", append se sym(**, *, +) ctitle(1) nocons dec(3)
	outreg2 tcosts tariff kl sl rd  using "$Tables/Table5_2.xls", append se noast ctitle(1) nocons dec(8)
	outreg2 tcosts tariff kl sl rd  using "$Tables/Table5_2.xls", append se noast stat(beta) ctitle(1beta) nocons dec(3)
** 5.2, col 2
areg fs tcosts tariff kl sl rd if goodshare==1, absorb(year) cluster(naics)
	outreg2 tcosts tariff kl sl rd using "$Tables/Table5_2.xls", append se sym(**, *, +) ctitle(2) nocons dec(3)
	outreg2 tcosts tariff kl sl rd using "$Tables/Table5_2.xls", append se noast ctitle(2) nocons dec(8)
	outreg2 tcosts tariff kl sl rd using "$Tables/Table5_2.xls", append se noast stat(beta) ctitle(2beta) nocons dec(3)
** 5.2, col 3
areg fs tcosts tariff buildl equipl sl rd if goodshare==1, absorb(year) cluster(naics)
	outreg2 tcosts tariff buildl equipl sl rd using "$Tables/Table5_2.xls", append se sym(**, *, +) ctitle(3) nocons dec(3)
	outreg2 tcosts tariff buildl equipl sl rd using "$Tables/Table5_2.xls", append se noast ctitle(3) nocons dec(8)
	outreg2 tcosts tariff buildl equipl sl rd using "$Tables/Table5_2.xls", append se noast stat(beta) ctitle(3beta) nocons dec(3)
** 5.2, col 4
areg fs tcosts tariff buildl equipl sl rd sigma dispersion if goodshare==1, absorb(year) cluster(naics)
	outreg2 tcosts tariff buildl equipl sl rd sigma dispersion using "$Tables/Table5_2.xls", append se sym(**, *, +) ctitle(4) nocons dec(3)
	outreg2 tcosts tariff buildl equipl sl rd sigma dispersion using "$Tables/Table5_2.xls", append se noast ctitle(4) nocons dec(8)
	outreg2 tcosts tariff buildl equipl sl rd sigma dispersion using "$Tables/Table5_2.xls", append se noast stat(beta) ctitle(4beta) nocons dec(3)

* MOVE TO COUNTRY/INDUSTRY DATA FOR THE LAST TWO COLUMNS OF THE TABLE
use "global_production_naics", clear
drop if naics=="33641X"
drop if isocode=="SSD"
* Note to Users: See the Data Appendix for a justification for dropping the composite industry IO33641X and the country "SSD"
 
egen exp_tot_agg=sum(exp_tot), by(naics year)
egen imp_tot_agg=sum(imp_tot), by(naics year)
gen fs= imp_tot / (imp_tot_agg + vship*1000000 - exp_tot_agg)
gen kl= log(cap / emp )
gen sl=log((emp-prode)/emp)
gen buildl=log(plant / emp )
gen equipl=log(equip / emp )
gen rd=log(0.001+ rd_complete)
gen goodshare=0
replace goodshare=1 if fs<=1 & fs>=0

egen ctyyear=group(isocode year)

** 5.2, col 5
areg fs tcosts tariff buildl equipl sl rd sigma dispersion if goodshare==1, absorb(ctyyear) cluster(naics)
	outreg2 tcosts tariff buildl equipl sl rd sigma dispersion using "$Tables/Table5_2.xls", append se sym(**, *, +) ctitle(5) nocons dec(3)
	outreg2 tcosts tariff buildl equipl sl rd sigma dispersion using "$Tables/Table5_2.xls", append se noast ctitle(5) nocons dec(8)
	outreg2 tcosts tariff buildl equipl sl rd sigma dispersion using "$Tables/Table5_2.xls", append se noast stat(beta) ctitle(5beta) nocons dec(3)
** 5.2, col 6
areg fs tcosts tariff buildl equipl sl rd sigma dispersion if goodshare==1 & imp_tot>0, absorb(ctyyear) cluster(naics)
	outreg2 tcosts tariff buildl equipl sl rd sigma dispersion using "$Tables/Table5_2.xls", append se sym(**, *, +) ctitle(6) nocons dec(3)
	outreg2 tcosts tariff buildl equipl sl rd sigma dispersion using "$Tables/Table5_2.xls", append se noast ctitle(6) nocons dec(8)
	outreg2 tcosts tariff buildl equipl sl rd sigma dispersion using "$Tables/Table5_2.xls", append se noast stat(beta) ctitle(6beta) nocons dec(3)


*************
* TABLE 5.3 *
*************
use "global_production_crossindustry_io2002", clear

gen fs= imp_tot / (imp_tot + vship*1000000 - exp_tot)
gen fs_gw_n = imp_tot*discountm_gw / (imp_tot*discountm_gw + vship*1000000*(xtdiscountm_gw+xtdiscountx_gw)/2 - exp_tot*discountx_gw )
gen fs_gw_nnt = imp_tot*discountm_gwnt / (imp_tot*discountm_gw + vship*1000000*(xtdiscountm_gw+xtdiscountx_gw)/2 - exp_tot*discountx_gw)

gen kl= log(cap / emp )
gen sl=log((emp-prode)/emp)
gen buildl=log(plant / emp )
gen equipl=log(equip / emp )

gen wkl= log(wcap / wemp )
gen wsl=log((wemp-wprode)/wemp)
gen wbuildl=log(wplant / wemp )
gen wequipl=log(wequip / wemp )

gen goodshare=0
replace goodshare=1 if fs<=1 & fs>=0
sum goodshare if goodshare~=1
gen goodshare_gw_n=0
gen extra_gw_drop=0
replace extra_gw_drop=1 if io2002=="325411" | io2002=="33299B"
replace goodshare_gw_n=1 if fs_gw_n<=1 & fs_gw_n>=0 & xtdiscountm_gw>0 & extra_gw_drop==0
sum goodshare_gw_n if goodshare_gw_n~=1
gen goodshare_gw_nnt=0
replace goodshare_gw_nnt=1 if fs_gw_nnt<=1 & fs_gw_nnt>=0 & xtdiscountm_gw>0 & extra_gw_drop==0
sum goodshare_gw_nnt if goodshare_gw_nnt~=1

** FIRST FOUR COLUMNS FOR TABLE 5.3 
** 5.3, col 1
areg fs tcosts tariff buildl equipl sl rd sigma dispersion if goodshare==1, absorb(year) cluster(io2002)
	outreg2 tcosts tariff buildl equipl sl rd sigma dispersion using "$Tables/Table5_3.xls", append se sym(**, *, +) ctitle(1) nocons dec(3)
	outreg2 tcosts tariff buildl equipl sl rd sigma dispersion using "$Tables/Table5_3.xls", append se noast ctitle(1) nocons dec(10)
	outreg2 tcosts tariff buildl equipl sl rd sigma dispersion using "$Tables/Table5_3.xls", append se noast stat(beta) ctitle(1beta) nocons dec(3)
** 5.3, col 2
areg fs tcosts tariff wbuildl wequipl wsl wrd wsigma dispersion if goodshare==1, absorb(year) cluster(io2002)
	outreg2 tcosts tariff wbuildl wequipl wsl wrd wsigma dispersion using "$Tables/Table5_3.xls", append se sym(**, *, +) ctitle(2) nocons dec(3)
	outreg2 tcosts tariff wbuildl wequipl wsl wrd wsigma dispersion using "$Tables/Table5_3.xls", append se noast ctitle(2) nocons dec(10)
	outreg2 tcosts tariff wbuildl wequipl wsl wrd wsigma dispersion using "$Tables/Table5_3.xls", append se noast stat(beta) ctitle(2beta) nocons dec(3)
** 5.3, col 3
areg fs_gw_n tcosts tariff wbuildl wequipl wsl wrd wsigma dispersion if goodshare_gw_n==1, absorb(year) cluster(io2002)
	outreg2 tcosts tariff wbuildl wequipl wsl wrd wsigma dispersion using "$Tables/Table5_3.xls", append se sym(**, *, +) ctitle(3) nocons dec(3)
	outreg2 tcosts tariff wbuildl wequipl wsl wrd wsigma dispersion using "$Tables/Table5_3.xls", append se noast ctitle(3) nocons dec(10)
	outreg2 tcosts tariff wbuildl wequipl wsl wrd wsigma dispersion using "$Tables/Table5_3.xls", append se noast stat(beta) ctitle(3beta) nocons dec(3)
** 5.3, col 4
areg fs_gw_nnt tcosts tariff wbuildl wequipl wsl wrd wsigma dispersion if goodshare_gw_nnt==1, absorb(year) cluster(io2002)
	outreg2 tcosts tariff wbuildl wequipl wsl wrd wsigma dispersion using "$Tables/Table5_3.xls", append se sym(**, *, +) ctitle(4) nocons dec(3)
	outreg2 tcosts tariff wbuildl wequipl wsl wrd wsigma dispersion using "$Tables/Table5_3.xls", append se noast ctitle(4) nocons dec(10)
	outreg2 tcosts tariff wbuildl wequipl wsl wrd wsigma dispersion using "$Tables/Table5_3.xls", append se noast stat(beta) ctitle(4beta) nocons dec(3)

* MOVE TO COUNTRY/INDUSTRY FOR FIXED EFFECTS
use "global_production_io2002", clear
drop if isocode=="SSD"
*drop if io2002=="334411"

egen exp_tot_agg=sum(exp_tot), by(io2002 year)
egen imp_tot_agg=sum(imp_tot), by(io2002 year)
egen exp_tot_gw_nagg=sum(exp_tot_gw), by(io2002 year)
egen imp_tot_gw_nagg=sum(imp_tot_gw), by(io2002 year)

gen fs= imp_tot / (imp_tot_agg + vship*1000000 - exp_tot_agg)
gen fs_gw_n = imp_tot*discountm_gw / (imp_tot_gw_nagg + vship*1000000*(i_xtdiscountm_gw+i_xtdiscountx_gw)/2 - exp_tot_gw_nagg )
gen fs_gw_nnt= imp_tot*discountm_gwnt / (imp_tot_gw_nagg + vship*1000000*(i_xtdiscountm_gw+i_xtdiscountx_gw)/2 - exp_tot_gw_nagg )

gen kl= log(cap / emp )
gen sl=log((emp-prode)/emp)
gen buildl=log(plant / emp )
gen equipl=log(equip / emp )

gen wkl= log(wcap / wemp )
gen wsl=log((wemp-wprode)/wemp)
gen wbuildl=log(wplant / wemp )
gen wequipl=log(wequip / wemp )

gen goodshare=0
replace goodshare=1 if fs<=1 & fs>=0
gen goodshare_gw_n=0
gen extra_gw_drop=0
replace extra_gw_drop=1 if io2002=="325411" | io2002=="33299B"
replace goodshare_gw_n=1 if fs_gw_n<=1 & fs_gw_n>=0 & i_xtdiscountm_gw>0 & extra_gw_drop==0
sum goodshare_gw_n if goodshare_gw_n~=1
gen goodshare_gw_nnt=0
replace goodshare_gw_nnt=1 if fs_gw_nnt<=1 & fs_gw_nnt>=0 & i_xtdiscountm_gw>0 & extra_gw_drop==0
sum fs_gw_nnt if (fs_gw_nnt<0 |  fs_gw_nnt>1) & extra_gw_drop==0

egen ctyyear=group(isocode year)

** TWO LAST COLUMNS OF TABLE 5.3
** 5.3, col 5
areg fs_gw_nnt tcosts tariff wbuildl wequipl wsl wrd wsigma dispersion if goodshare_gw_nnt==1, absorb(ctyyear) cluster(io2002)
	outreg2 tcosts tariff wbuildl wequipl wsl wrd wsigma dispersion using "$Tables/Table5_3.xls", append se sym(**, *, +) ctitle(5) nocons dec(3)
	outreg2 tcosts tariff wbuildl wequipl wsl wrd wsigma dispersion using "$Tables/Table5_3.xls", append se noast ctitle(5) nocons dec(10)
	outreg2 tcosts tariff wbuildl wequipl wsl wrd wsigma dispersion using "$Tables/Table5_3.xls", append se noast stat(beta) ctitle(5beta) nocons dec(3)

** 5.3, col 6
areg fs_gw_nnt tcosts tariff wbuildl wequipl wsl wrd wsigma dispersion if goodshare_gw_nnt==1 & fs_gw_nnt>0, absorb(ctyyear) cluster(io2002)
	outreg2 tcosts tariff wbuildl wequipl wsl wrd wsigma dispersion using "$Tables/Table5_3.xls", append se sym(**, *, +) ctitle(6) nocons dec(3)
	outreg2 tcosts tariff wbuildl wequipl wsl wrd wsigma dispersion using "$Tables/Table5_3.xls", append se noast ctitle(6) nocons dec(10)
	outreg2 tcosts tariff wbuildl wequipl wsl wrd wsigma dispersion using "$Tables/Table5_3.xls", append se noast stat(beta) ctitle(6beta) nocons dec(3)


*************
* TABLE 5.6 *
*************
use "global_production_crossindustry_io2002", clear

gen fs= imp_tot / (imp_tot + vship*1000000 - exp_tot)
gen fs_gw_n = imp_tot*discountm_gw / (imp_tot*discountm_gw + vship*1000000*(xtdiscountm_gw+xtdiscountx_gw)/2 - exp_tot*discountx_gw)
gen fs_gw_nnt = imp_tot*discountm_gwnt/ (imp_tot*discountm_gw + vship*1000000*(xtdiscountm_gw+xtdiscountx_gw)/2 - exp_tot*discountx_gw)

gen kl= log(cap / emp )
gen sl=log((emp-prode)/emp)
gen buildl=log(plant / emp )
gen equipl=log(equip / emp )

gen wkl= log(wcap / wemp )
gen wsl=log((wemp-wprode)/wemp)
gen wbuildl=log(wplant / wemp )
gen wequipl=log(wequip / wemp )

gen goodshare=0
replace goodshare=1 if fs<=1 & fs>=0
sum goodshare if goodshare~=1
gen goodshare_gw_n=0
gen extra_gw_drop=0
replace extra_gw_drop=1 if io2002=="325411" | io2002=="33299B"
replace goodshare_gw_n=1 if fs_gw_n<=1 & fs_gw_n>=0 & xtdiscountm_gw>0 & extra_gw_drop==0
sum goodshare_gw_n if goodshare_gw_n~=1
gen goodshare_gw_nnt=0
replace goodshare_gw_nnt=1 if fs_gw_nnt<=1 & fs_gw_nnt>=0 & xtdiscountm_gw>0 & extra_gw_drop==0


* STANDARDIZE VARIABLES
keep if goodshare_gw_nnt==1

local varlist fs_gw_nnt tcosts tariff wbuildl wequipl wsl wrd wsigma dispersion ext_dep tang nunn_c lev_c bjrs_c cos_c nunn_s input_subst downmeasure 
foreach x of local varlist { 
	egen mean_`x' = mean(`x')
	egen sd_`x' = sd(`x')
	replace `x' = (`x' - mean_`x')/sd_`x'
	cap drop mean_`x' sd_`x'
	}
	
** 5.6, col 1
foreach var in ext_dep tang nunn_c lev_c cos_c bjrs_c  nunn_s input_subst downmeasure {
areg fs_gw_nnt tcosts tariff wbuildl wequipl wsl wrd wsigma dispersion `var' if goodshare_gw_nnt==1, absorb(year) cluster(io2002)
	outreg2 using "$Tables/Table5_6_col1-3.xls", append se nocons ctitle(1) sym(**, *, +) dec(3) keep(`var')
}
	
** 5.6, col 4
areg fs_gw_nnt tcosts tariff wbuildl wequipl wsl wrd wsigma dispersion ext_dep nunn_c nunn_s input_subst downmeasure if goodshare_gw_nnt==1, absorb(year) cluster(io2002)
	outreg2 using "$Tables/Table5_6_col4-6.xls", append se nocons ctitle(4) sym(**, *, +) dec(3) keep(ext_dep nunn_c nunn_s input_subst downmeasure)


* MOVE TO COUNTRY/INDUSTRY FOR FIXED EFFECTS
use "global_production_io2002", clear
drop if isocode=="SSD"
*drop if io2002=="334411"

egen exp_tot_agg=sum(exp_tot), by(io2002 year)
egen imp_tot_agg=sum(imp_tot), by(io2002 year)
egen exp_tot_gw_nagg=sum(exp_tot_gw), by(io2002 year)
egen imp_tot_gw_nagg=sum(imp_tot_gw), by(io2002 year)

gen fs= imp_tot / (imp_tot_agg + vship*1000000 - exp_tot_agg)
gen fs_gw_n = imp_tot*discountm_gw / (imp_tot_gw_nagg + vship*1000000*(i_xtdiscountm_gw+i_xtdiscountx_gw)/2 - exp_tot_gw_nagg )
gen fs_gw_nnt = imp_tot*discountm_gwnt / (imp_tot_gw_nagg + vship*1000000*(i_xtdiscountm_gw+i_xtdiscountx_gw)/2 - exp_tot_gw_nagg )

gen kl= log(cap / emp )
gen sl=log((emp-prode)/emp)
gen buildl=log(plant / emp )
gen equipl=log(equip / emp )

gen wkl= log(wcap / wemp )
gen wsl=log((wemp-wprode)/wemp)
gen wbuildl=log(wplant / wemp )
gen wequipl=log(wequip / wemp )

gen goodshare=0
replace goodshare=1 if fs<=1 & fs>=0
sum goodshare if goodshare~=1
gen goodshare_gw_n=0
gen extra_gw_drop=0
replace extra_gw_drop=1 if io2002=="325411" | io2002=="33299B"
replace goodshare_gw_n=1 if fs_gw_n<=1 & fs_gw_n>=0 & i_xtdiscountm_gw>0 & extra_gw_drop==0
sum goodshare_gw_n if goodshare_gw_n~=1
gen goodshare_gw_nnt=0
replace goodshare_gw_nnt=1 if fs_gw_nnt<=1 & fs_gw_nnt>=0 & i_xtdiscountm_gw>0 & extra_gw_drop==0

gen positive_flow=0
replace positive_flow=1 if fs_gw_nnt>0

egen ctyyear=group(isocode year)

* STANDARDIZE VARIABLES
keep if goodshare_gw_nnt==1

local varlist fs_gw_nnt tcosts tariff wbuildl wequipl wsl wrd wsigma dispersion ext_dep tang nunn_c lev_c bjrs_c cos_c nunn_s input_subst downmeasure
foreach x of local varlist { 
	egen mean_`x' = mean(`x')
	egen sd_`x' = sd(`x')
	replace `x' = (`x' - mean_`x')/sd_`x'
	cap drop mean_`x' sd_`x'
	}

** 5.6, col 2
foreach var in ext_dep tang nunn_c lev_c cos_c bjrs_c  nunn_s input_subst downmeasure {
areg fs_gw_nnt tcosts tariff wbuildl wequipl wsl wrd wsigma dispersion `var' if goodshare_gw_nnt==1, absorb(ctyyear) cluster(io2002)
	outreg2 using "$Tables/Table5_6_col1-3.xls", append se nocons ctitle(2) sym(**, *, +) dec(3) keep(`var')
}

** 5.6, col 5
areg fs_gw_nnt tcosts tariff wbuildl wequipl wsl wrd wsigma dispersion ext_dep nunn_c nunn_s input_subst downmeasure if goodshare_gw_nnt==1, absorb(ctyyear) cluster(io2002)
	outreg2 using "$Tables/Table5_6_col4-6.xls", append se nocons ctitle(5) sym(**, *, +) dec(3) keep(ext_dep nunn_c nunn_s input_subst downmeasure)


* STANDARDIZE VARIABLES
keep if positive_flow==1

local varlist fs_gw_nnt tcosts tariff wbuildl wequipl wsl wrd wsigma dispersion ext_dep tang nunn_c lev_c bjrs_c cos_c nunn_s input_subst downmeasure 
foreach x of local varlist { 
	egen mean_`x' = mean(`x')
	egen sd_`x' = sd(`x')
	replace `x' = (`x' - mean_`x')/sd_`x'
	cap drop mean_`x' sd_`x'
	}

** 5.6, col 3
foreach var in ext_dep tang nunn_c lev_c cos_c bjrs_c nunn_s input_subst downmeasure {
areg fs_gw_nnt tcosts tariff wbuildl wequipl wsl wrd wsigma dispersion `var' if goodshare_gw_nnt==1, absorb(ctyyear) cluster(io2002)
	outreg2 using "$Tables/Table5_6_col1-3.xls", append se nocons ctitle(3) sym(**, *, +) dec(3) keep(`var')
}

** 5.6, col 6
areg fs_gw_nnt tcosts tariff wbuildl wequipl wsl wrd wsigma dispersion ext_dep nunn_c nunn_s input_subst downmeasure if goodshare_gw_nnt==1, absorb(ctyyear) cluster(io2002)
	outreg2 using "$Tables/Table5_6_col4-6.xls", append se nocons ctitle(6) sym(**, *, +) dec(3) keep(ext_dep nunn_c nunn_s input_subst downmeasure)
	
	
*************
* TABLE 5.7 *
*************
use "global_production_io2002", clear
drop if isocode=="SSD"
*drop if io2002=="334411"

egen exp_tot_agg=sum(exp_tot), by(io2002 year)
egen imp_tot_agg=sum(imp_tot), by(io2002 year)
egen exp_tot_gw_nagg=sum(exp_tot_gw), by(io2002 year)
egen imp_tot_gw_nagg=sum(imp_tot_gw), by(io2002 year)

gen fs= imp_tot / (imp_tot_agg + vship*1000000 - exp_tot_agg)
gen fs_gw_n = imp_tot*discountm_gw / (imp_tot_gw_nagg + vship*1000000*(i_xtdiscountm_gw+i_xtdiscountx_gw)/2 - exp_tot_gw_nagg )
gen fs_gw_nnt = imp_tot*discountm_gwnt / (imp_tot_gw_nagg + vship*1000000*(i_xtdiscountm_gw+i_xtdiscountx_gw)/2 - exp_tot_gw_nagg )

gen logfs=ln(fs)
gen logfs_gw=ln(fs_gw_n)
gen logfs_gw_nt=ln(fs_gw_nnt)

gen kl= log(cap / emp )
gen sl=log((emp-prode)/emp)

gen wkl= log(wcap / wemp )
gen wsl=log((wemp-wprode)/wemp)
gen wequipl=log(wequip / wemp )

pca wequipl wsl wrd
predict whead wheadscore

* GENERATE INTERACTIONS
gen k_k=kl*lK_L
gen s_s=sl*log(yr_sch)

gen nunn_rule=nunn_c*rule_of_law
gen lev_rule=lev_c*rule_of_law
gen bjrs_rule=bjrs_c*rule_of_law
gen cos_rule=cos_c*rule_of_law
gen cos_s=cos_c*log(yr_sch)
gen rz=ext_dep*log(private_credit)
gen braun=tang*log(private_credit)
gen svol_flex=sales_vol*flex

gen nunn_gdp_inter1=nunn_c*log(rgdpch)
gen lev_gdp_inter1=lev_c*log(rgdpch)
gen bjrs_gdp_inter1=bjrs_c*log(rgdpch)
gen cos_gdp_inter1=cos_c*log(rgdpch)
gen rz_gdp_inter1=rz*log(rgdpch)
gen braun_gdp_inter1=tang*log(rgdpch)
gen svol_gdp_inter1=sales_vol*log(rgdpch)


* CREATING INTERACTIONS OF SECTOR DUMMIES WITH GDP
quietly tab io2002, ge(sectdum)
foreach i of numlist 1/253{
gen sectdum_gdp`i'=sectdum`i'*log(rgdpch)
}

gen goodshare=0
replace goodshare=1 if fs<=1 & fs>=0
sum goodshare if goodshare~=1
gen goodshare_gw_n=0
gen extra_gw_drop=0
replace extra_gw_drop=1 if io2002=="325411" | io2002=="33299B"
replace goodshare_gw_n=1 if fs_gw_n<=1 & fs_gw_n>=0 & i_xtdiscountm_gw>0 & extra_gw_drop==0
sum goodshare_gw_n if goodshare_gw_n~=1
gen goodshare_gw_nnt=0
replace goodshare_gw_nnt=1 if fs_gw_nnt<=1 & fs_gw_nnt>=0 & i_xtdiscountm_gw>0 & extra_gw_drop==0

egen ctyyear=group(isocode year)
egen ctyind=group (isocode io2002)

* Keep only necessary variables
local depvarlist "logfs logfs_gw logfs_gw_nt"
local indepvarlist1 "k_k s_s nunn_rule lev_rule cos_s cos_rule bjrs_rule rz braun svol_flex"
keep isocode io2002 year `depvarlist' `indepvarlist1' cty* goodshare* *gdp_inter1 sectdum_gdp*

*REGRESSIONS ONE VARIABLE AT A TIME + TWO MORE FOR TABLE 5_7
local option_xls "append se noast nocons dec(10)"
local option_xls1 "append se stat(beta) ctitle(1beta) nocons dec(3)"
local option_xls2 "append se stat(beta) ctitle(2beta) nocons dec(3)"
local option_xls3 "append se stat(beta) nocons dec(3)"

** 5.7, col 1 & 2
xi: areg logfs i.io2002 k_k s_s nunn_rule if goodshare==1, absorb(ctyyear) cluster(ctyind)
	outreg2 using "$Tables/Table5_7.xls", `option_xls' keep(nunn_rule)
	outreg2 using "$Tables/Table5_7.xls", `option_xls1' keep(nunn_rule)
xi: areg logfs_gw_nt i.io2002 k_k s_s nunn_rule if goodshare_gw_nnt==1, absorb(ctyyear) cluster(ctyind)
	outreg2 using "$Tables/Table5_7.xls", `option_xls' keep(nunn_rule)
	outreg2 using "$Tables/Table5_7.xls", `option_xls2' keep(nunn_rule)

xi: areg logfs i.io2002 k_k s_s lev_rule if goodshare==1, absorb(ctyyear) cluster(ctyind)
	outreg2 using "$Tables/Table5_7.xls", `option_xls' keep(lev_rule)
	outreg2 using "$Tables/Table5_7.xls", `option_xls1' keep(lev_rule)
xi: areg logfs_gw_nt i.io2002 k_k s_s lev_rule if goodshare_gw_nnt==1, absorb(ctyyear) cluster(ctyind)
	outreg2 using "$Tables/Table5_7.xls", `option_xls' keep(lev_rule)
	outreg2 using "$Tables/Table5_7.xls", `option_xls2' keep(lev_rule)

xi: areg logfs i.io2002 k_k s_s cos_s cos_rule if goodshare==1, absorb(ctyyear) cluster(ctyind)
	outreg2 using "$Tables/Table5_7.xls", `option_xls' keep(cos_rule)
	outreg2 using "$Tables/Table5_7.xls", `option_xls1' keep(cos_rule)
xi: areg logfs_gw_nt i.io2002 k_k s_s cos_s cos_rule if goodshare_gw_nnt==1, absorb(ctyyear) cluster(ctyind)
	outreg2 using "$Tables/Table5_7.xls", `option_xls' keep(cos_rule)
	outreg2 using "$Tables/Table5_7.xls", `option_xls2' keep(cos_rule)

xi: areg logfs i.io2002 k_k s_s bjrs_rule if goodshare==1, absorb(ctyyear) cluster(ctyind)
	outreg2 using "$Tables/Table5_7.xls", `option_xls' keep(bjrs_rule)
	outreg2 using "$Tables/Table5_7.xls", `option_xls1' keep(bjrs_rule)
xi: areg logfs_gw_nt i.io2002 k_k s_s bjrs_rule if goodshare_gw_nnt==1, absorb(ctyyear) cluster(ctyind)
	outreg2 using "$Tables/Table5_7.xls", `option_xls' keep(bjrs_rule)
	outreg2 using "$Tables/Table5_7.xls", `option_xls2' keep(bjrs_rule)

xi: areg logfs i.io2002 k_k s_s rz if goodshare==1, absorb(ctyyear) cluster(ctyind)
	outreg2 using "$Tables/Table5_7.xls", `option_xls' keep(rz)
	outreg2 using "$Tables/Table5_7.xls", `option_xls1' keep(rz)
xi: areg logfs_gw_nt i.io2002 k_k s_s rz if goodshare_gw_nnt==1, absorb(ctyyear) cluster(ctyind)
	outreg2 using "$Tables/Table5_7.xls", `option_xls' keep(rz)
	outreg2 using "$Tables/Table5_7.xls", `option_xls2' keep(rz)

xi: areg logfs i.io2002 k_k s_s braun if goodshare==1, absorb(ctyyear) cluster(ctyind)
	outreg2 using "$Tables/Table5_7.xls", `option_xls' keep(braun)
	outreg2 using "$Tables/Table5_7.xls", `option_xls1' keep(braun)
xi: areg logfs_gw_nt i.io2002 k_k s_s braun if goodshare_gw_nnt==1, absorb(ctyyear) cluster(ctyind)
	outreg2 using "$Tables/Table5_7.xls", `option_xls' keep(braun)
	outreg2 using "$Tables/Table5_7.xls", `option_xls2' keep(braun)	

xi: areg logfs i.io2002 k_k s_s svol_flex if goodshare==1, absorb(ctyyear) cluster(ctyind)
	outreg2 using "$Tables/Table5_7.xls", `option_xls' keep(svol_flex)
	outreg2 using "$Tables/Table5_7.xls", `option_xls1' keep(svol_flex)	
xi: areg logfs_gw_nt i.io2002 k_k s_s svol_flex if goodshare_gw_nnt==1, absorb(ctyyear) cluster(ctyind)
	outreg2 using "$Tables/Table5_7.xls", `option_xls' keep(svol_flex)
	outreg2 using "$Tables/Table5_7.xls", `option_xls2' keep(svol_flex)	

* EVERYTHING REGRESSIONS
local var "k_k s_s nunn_rule lev_rule cos_s cos_rule bjrs_rule rz braun svol_flex"
local var2 "k_k s_s nunn_rule lev_rule cos_rule bjrs_rule rz braun svol_flex"
** 5.7, col 3
xi: areg logfs_gw_nt i.io2002 `var' if goodshare_gw_nnt==1, absorb(ctyyear) cluster(ctyind)
	outreg2 using "$Tables/Table5_7.xls", `option_xls' keep(`var2') ctitle(3) 
	outreg2 using "$Tables/Table5_7.xls", `option_xls3' keep(`var2') ctitle(3beta) 	
** 5.7, col 4
xi: areg logfs_gw_nt i.io2002 *gdp_inter1 `var' if goodshare_gw_nnt==1, absorb(ctyyear) cluster(ctyind)
	outreg2 using "$Tables/Table5_7.xls", `option_xls' keep(`var2') ctitle(4) 
	outreg2 using "$Tables/Table5_7.xls", `option_xls3' keep(`var2') ctitle(4beta) 
** 5.7, col 5
xi: areg logfs_gw_nt i.io2002 sectdum_gdp* `var' if goodshare_gw_nnt==1, absorb(ctyyear) cluster(ctyind)
	outreg2 using "$Tables/Table5_7.xls", `option_xls' keep(`var2') ctitle(5) 
	outreg2 using "$Tables/Table5_7.xls", `option_xls3' keep(`var2') ctitle(5beta) 

*************
* TABLE 5.8 *
*************
set more off
use "global_production_io2002", clear
drop if isocode=="SSD"
*drop if io2002=="334411"

egen exp_tot_agg=sum(exp_tot), by(io2002 year)
egen imp_tot_agg=sum(imp_tot), by(io2002 year)
egen exp_tot_gw_nagg=sum(exp_tot_gw), by(io2002 year)
egen imp_tot_gw_nagg=sum(imp_tot_gw), by(io2002 year)

gen fs= imp_tot / (imp_tot_agg + vship*1000000 - exp_tot_agg)
gen fs_gw_n = imp_tot*discountm_gw / (imp_tot_gw_nagg + vship*1000000*(i_xtdiscountm_gw+i_xtdiscountx_gw)/2 - exp_tot_gw_nagg )
gen fs_gw_nnt = imp_tot*discountm_gwnt / (imp_tot_gw_nagg + vship*1000000*(i_xtdiscountm_gw+i_xtdiscountx_gw)/2 - exp_tot_gw_nagg )

gen logfs=ln(fs)
gen logfs_gw=ln(fs_gw_n)
gen logfs_gw_nt=ln(fs_gw_nnt)

gen kl= log(cap / emp )
gen sl=log((emp-prode)/emp)

gen wkl= log(wcap / wemp )
gen wsl=log((wemp-wprode)/wemp)
gen wequipl=log(wequip / wemp )

pca wequipl wsl wrd
predict whead wheadscore

* GENERATE INTERACTIONS
gen k_k=kl*lK_L
gen s_s=sl*log(yr_sch)

gen input_subst_rule=input_subst*rule_of_law
gen wsigma_rule=wsigma*rule_of_law
gen nunns_rule=nunn_s*rule_of_law
gen whead_dev=whead*private_credit
gen whead_rule=whead*rule_of_law

gen input_subst_gdp_inter2=input_subst*log(rgdpch)
gen wsigma_gdp_inter2=wsigma*log(rgdpch)
gen nunns_gdp_inter2=nunns*log(rgdpch)
gen whead_gdp_inter2=whead*log(rgdpch)

* CREATING INTERACTIONS OF SECTOR DUMMIES WITH GDP
quietly tab io2002, ge(sectdum)
foreach i of numlist 1/253{
gen sectdum_gdp`i'=sectdum`i'*log(rgdpch)
}

gen goodshare=0
replace goodshare=1 if fs<=1 & fs>=0
sum goodshare if goodshare~=1
gen goodshare_gw_n=0
gen extra_gw_drop=0
replace extra_gw_drop=1 if io2002=="325411" | io2002=="33299B"
replace goodshare_gw_n=1 if fs_gw_n<=1 & fs_gw_n>=0 & i_xtdiscountm_gw>0 & extra_gw_drop==0
sum goodshare_gw_n if goodshare_gw_n~=1
gen goodshare_gw_nnt=0
replace goodshare_gw_nnt=1 if fs_gw_nnt<=1 & fs_gw_nnt>=0 & i_xtdiscountm_gw>0 & extra_gw_drop==0

egen ctyyear=group(isocode year)
egen ctyind=group (isocode io2002)

	// Keep only necessary variables
local depvarlist "logfs logfs_gw logfs_gw_nt"
local indepvarlist2 "k_k s_s tc tar input_subst_rule wsigma_rule nunns_rule whead_dev whead_rule"
keep isocode io2002 year `depvarlist' `indepvarlist2' cty* goodshare* *gdp_inter2 sectdum_gdp*

local option "append tex label se sym(**, *, +) stat(beta) nocons dec(3)"
local option1 "append tex label se sym(**, *, +) stat(beta) ctitle(1beta) nocons dec(3)"
local option2 "append tex label se sym(**, *, +) stat(beta) ctitle(2beta) nocons dec(3)"
local option_xls "append se noast nocons dec(10)"
local option_xls1 "append se stat(beta) ctitle(beta) nocons dec(3)"
local option_xls3 "append se stat(beta) nocons dec(3)"

** 5.8, col 1
xi: areg logfs i.io2002 k_k s_s tc tar if goodshare==1, absorb(ctyyear) cluster(ctyind)
	outreg2 using "$Tables/Table5_8.xls", replace keep(k_k s_s tc tar) se noast nocons dec(10)
	outreg2 using "$Tables/Table5_8.xls", `option_xls1' keep(k_k s_s tc tar)

** 5.8, col 2
xi: areg logfs_gw_nt i.io2002 k_k s_s tc tar if goodshare_gw_nnt==1, absorb(ctyyear) cluster(ctyind)
	outreg2 using "$Tables/Table5_8.xls", `option_xls' keep(tc tar k_k s_s)
	outreg2 using "$Tables/Table5_8.xls", `option_xls1' keep(tc tar k_k s_s)	
	
** 5.8, col 3
xi: areg logfs_gw_nt i.io2002 k_k s_s tc tar input_subst_rule if goodshare_gw_nnt==1, absorb(ctyyear) cluster(ctyind)
	outreg2 using "$Tables/Table5_8.xls", `option_xls' keep(input_subst_rule)
	outreg2 using "$Tables/Table5_8.xls", `option_xls1' keep(input_subst_rule)
	
xi: areg logfs_gw_nt i.io2002 k_k s_s tc tar wsigma_rule if goodshare_gw_nnt==1, absorb(ctyyear) cluster(ctyind)
	outreg2 using "$Tables/Table5_8.xls", `option_xls' keep(wsigma_rule)
	outreg2 using "$Tables/Table5_8.xls", `option_xls1' keep(wsigma_rule)

xi: areg logfs_gw_nt i.io2002 k_k s_s tc tar nunns_rule if goodshare_gw_nnt==1, absorb(ctyyear) cluster(ctyind)
	outreg2 using "$Tables/Table5_8.xls", `option_xls' keep(nunns_rule)
	outreg2 using "$Tables/Table5_8.xls", `option_xls1' keep(nunns_rule)
	
xi: areg logfs_gw_nt i.io2002 k_k s_s tc tar whead_dev if goodshare_gw_nnt==1, absorb(ctyyear) cluster(ctyind)
	outreg2 using "$Tables/Table5_8.xls", `option_xls' keep(whead_dev)
	outreg2 using "$Tables/Table5_8.xls", `option_xls1' keep(whead_dev)
	
xi: areg logfs_gw_nt i.io2002 k_k s_s tc tar whead_rule if goodshare_gw_nnt==1, absorb(ctyyear) cluster(ctyind)
	outreg2 using "$Tables/Table5_8.xls", `option_xls' keep(whead_rule)
	outreg2 using "$Tables/Table5_8.xls", `option_xls1' keep(whead_rule)

** 5.8, col 4
local var "k_k s_s tc tar input_subst_rule wsigma_rule nunns_rule whead_dev whead_rule"
xi: areg logfs_gw_nt i.io2002 `var' if goodshare_gw_nnt==1, absorb(ctyyear) cluster(ctyind)
	outreg2 using "$Tables/Table5_8.xls", `option_xls' keep(`var') ctitle(3) 
	outreg2 using "$Tables/Table5_8.xls", `option_xls3' keep(`var') ctitle(4beta)
	
** 5.8, col 5
xi: areg logfs_gw_nt i.io2002 *gdp_inter2 `var' if goodshare_gw_nnt==1, absorb(ctyyear) cluster(ctyind)
	outreg2 using "$Tables/Table5_8.xls", `option_xls' keep(`var') ctitle(4) 
	outreg2 using "$Tables/Table5_8.xls", `option_xls3' keep(`var') ctitle(5beta)
	
** 5.8, col 6
xi: areg logfs_gw_nt i.io2002 sectdum_gdp* `var' if goodshare_gw_nnt==1, absorb(ctyyear) cluster(ctyind)
	outreg2 using "$Tables/Table5_8.xls", `option_xls' keep(`var') ctitle(5) 
	outreg2 using "$Tables/Table5_8.xls", `option_xls3' keep(`var') ctitle(6beta)
	
log close
exit
